<img src="https://gwpy.github.io/images/gwpy_1200.png" alt="GWpy logo" style="width: 400px;" />


GWpy's new home: [https://gwpy.github.io](https://gwpy.github.io)
-----------------------------------------------------------------

GWpy is a collaboration-driven Python package providing tools for studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface to the common time-domain and frequency-domain data produced by the LIGO and Virgo instruments and their analysis, with easy-to-follow tutorials at each step.

All members of the LIGO Scientific Collaboration and the Virgo Collaboration can and should claim authorship of this package, given that I've stolen most of other people's code and wrapped it in a user-friendly python package.

Project status
--------------
[![PyPI version](https://badge.fury.io/py/gwpy.svg)](http://badge.fury.io/py/gwpy)  
[![Build Status](https://travis-ci.org/gwpy/gwpy.svg?branch=master)](https://travis-ci.org/gwpy/gwpy)  
[![Coverage Status](https://coveralls.io/repos/gwpy/gwpy/badge.svg)](https://coveralls.io/r/gwpy/gwpy)  
[![Code Climate](https://codeclimate.com/github/gwpy/gwpy/badges/gpa.svg)](https://codeclimate.com/github/gwpy/gwpy)  
[![Code Health](https://landscape.io/github/gwpy/gwpy/master/landscape.svg?style=flat)](https://landscape.io/github/gwpy/gwpy/master)  
[![Gitter](https://badges.gitter.im/Join Chat.svg)](https://gitter.im/gwpy/gwpy?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
